@@ -5,15 +5,15 @@ modelled output based on this data. The types of data currently included are:
  - Fixed domain sensitivity maps known as footprints (FootprintData)
  - Fixed domain flux maps (FluxData) - multiple maps can be included and
  referenced by source name
-
-TODO: Also need to incorporate boundary conditions
+ - Fixed domain vertical curtains at each boundary (BoundaryConditionsData)
 
 A ModelScenario instance can be created by searching the object store manually
 and providing these outputs:
->>> obs = get_obs_surface(site, species, ...)
->>> footprint = get_footprint(site, domain, ...)
->>> flux = get_flux(species, source, ...)
->>> model = ModelScenario(obs=obs, footprint=footprint, flux=flux)
+>>> obs = get_obs_surface(site, species, inlet, ...)
+>>> footprint = get_footprint(site, domain, inlet, ...)
+>>> flux = get_flux(species, source, domain, ...)
+>>> bc = get_bc(species, domain, bc_input, ...)
+>>> model = ModelScenario(obs=obs, footprint=footprint, flux=flux, bc=bc)
 
 A ModelScenario instance can also be created using keywords to search the object store:
 >>> model = ModelScenario(site,
@@ -22,6 +22,7 @@ A ModelScenario instance can also be created using keywords to search the object
                           network,
                           domain,
                           sources=sources,
+                          bc_input=bc_input,
                           start_date=start_date,
                           end_date=end_date)
 
@@ -30,23 +31,36 @@ A ModelScenario instance can also be initialised and then populated after creati
 >>> model.add_obs(obs=obs)
 >>> model.add_footprint(site, inlet, domain, ...)
 >>> model.add_flux(species, domain, sources, ...)
+>>> model.add_bc(species, domain, bc_input, ...)
 
 Once created, methods can be called on ModelScenario which will combine these
 data sources and cache the outputs (if requested) to make for quicker calculation.
 
 >>> modelled_obs = model.calc_modelled_obs()
+>>> modelled_baseline = model.calc_modelled_baseline()
 >>> combined_data = model.footprints_data_merge()
 
 If some input types needed for these operations are missing, the user will be alerted
 on which data types are missing.
 """
 
+import logging
 from typing import Any, Dict, List, Literal, Optional, Sequence, Tuple, Union, cast
 
 import numpy as np
 from openghg.dataobjects import BoundaryConditionsData, FluxData, FootprintData, ObsData
-from openghg.retrieve import get_bc, get_flux, get_footprint, get_obs_surface, search
+from openghg.retrieve import (
+    get_obs_surface,
+    get_bc,
+    get_flux,
+    get_footprint,
+    search_surface,
+    search_bc,
+    search_flux,
+    search_footprints,
+)
 from openghg.util import synonyms
+from openghg.types import SearchError
 from pandas import Timestamp
 from xarray import DataArray, Dataset
 
@@ -64,6 +78,10 @@ ParamType = Union[List[Dict[str, Optional[str]]], Dict[str, Optional[str]]]
 methodType = Optional[Literal["nearest", "pad", "ffill", "backfill", "bfill"]]
 
 
+logger = logging.getLogger("openghg.analyse")
+logger.setLevel(logging.DEBUG)  # Have to set level for logger as well as handler
+
+
 class ModelScenario:
     """
     This class stores together observation data with ancillary data and allows
@@ -75,6 +93,7 @@ class ModelScenario:
         site: Optional[str] = None,
         species: Optional[str] = None,
         inlet: Optional[str] = None,
+        height: Optional[str] = None,
         network: Optional[str] = None,
         domain: Optional[str] = None,
         model: Optional[str] = None,
@@ -105,6 +124,7 @@ class ModelScenario:
             site : Site code e.g. "TAC"
             species : Species code e.g. "ch4"
             inlet : Inlet value e.g. "10m"
+            height: Alias for inlet.
             network : Network name e.g. "AGAGE"
             domain : Domain name e.g. "EUROPE"
             model : Model name used in creation of footprint e.g. "NAME"
@@ -116,7 +136,6 @@ class ModelScenario:
             obs : Supply ObsData object directly (e.g. from get_obs...() functions)
             footprint : Supply FootprintData object directly (e.g. from get_footprint() function)
             flux : Supply FluxData object directly (e.g. from get_flux() function)
-
         Returns:
             None
 
@@ -139,6 +158,7 @@ class ModelScenario:
             site=site,
             species=species,
             inlet=inlet,
+            height=height,
             network=network,
             start_date=start_date,
             end_date=end_date,
@@ -158,6 +178,7 @@ class ModelScenario:
         self.add_footprint(
             site=site,
             inlet=inlet,
+            height=height,
             domain=domain,
             model=model,
             metmodel=metmodel,
@@ -196,7 +217,7 @@ class ModelScenario:
 
         # TODO: Check species, site etc. values align between inputs?
 
-    def _get_data(self, keywords: ParamType, input_type: str) -> Any:
+    def _get_data(self, keywords: ParamType, data_type: str) -> Any:
         """
         Use appropriate get function to search for data in object store.
         """
@@ -208,11 +229,15 @@ class ModelScenario:
             "boundary_conditions": get_bc,
         }
 
-        # TODO: Add/write footprint and flux search? What's the syntax?
-        search_functions = {"obs_surface": search}
+        search_functions = {
+            "obs_surface": search_surface,
+            "footprint": search_footprints,
+            "flux": search_flux,
+            "boundary_conditions": search_bc,
+        }
 
-        get_fn = get_functions[input_type]
-        search_fn = search_functions.get(input_type)
+        get_fn = get_functions[data_type]
+        search_fn = search_functions.get(data_type)
 
         if isinstance(keywords, dict):
             keywords = [keywords]
@@ -221,23 +246,24 @@ class ModelScenario:
         for i, keyword_set in enumerate(keywords):
             try:
                 data = get_fn(**keyword_set)  # type:ignore
-            except (ValueError, AttributeError):
+            except (SearchError, AttributeError):
                 num = i + 1
                 if num == num_checks:
-                    print(f"Unable to add {input_type} data based on keywords supplied.")
+                    print(f"Unable to add {data_type} data based on keywords supplied.")
                     print(" Inputs - \n")
                     for key, value in keyword_set.items():
                         print(f" {key}: {value}\n")
                     if search_fn is not None:
-                        data_search = search_fn(**keyword_set)
+                        data_search = search_fn(**keyword_set)  # type:ignore
                         print("---- Search results ---")
+                        print(f"Number of results returned: {len(data_search)}")
                         print(data_search)
                         # TODO: If we can determine how many results are returned from search
                         # we can use this to give better information about why no data has
                         # been found for these inputs.
                 data = None
             else:
-                print(f"Adding {input_type} to model scenario")
+                print(f"Adding {data_type} to model scenario")
                 break
 
         return data
@@ -247,6 +273,7 @@ class ModelScenario:
         site: Optional[str] = None,
         species: Optional[str] = None,
         inlet: Optional[str] = None,
+        height: Optional[str] = None,
         network: Optional[str] = None,
         start_date: Optional[Union[str, Timestamp]] = None,
         end_date: Optional[Union[str, Timestamp]] = None,
@@ -255,11 +282,17 @@ class ModelScenario:
         """
         Add observation data based on keywords or direct ObsData object.
         """
-        from openghg.util import clean_string
+        from openghg.util import clean_string, format_inlet
 
         # Search for obs data based on keywords
         if site is not None and obs is None:
             site = clean_string(site)
+
+            if height is not None and inlet is None:
+                inlet = height
+            inlet = clean_string(inlet)
+            inlet = format_inlet(inlet)
+
             # search for obs based on suitable keywords - site, species, inlet
             obs_keywords = {
                 "site": site,
@@ -270,7 +303,7 @@ class ModelScenario:
                 "end_date": end_date,
             }
 
-            obs = self._get_data(obs_keywords, input_type="obs_surface")
+            obs = self._get_data(obs_keywords, data_type="obs_surface")
 
         self.obs = obs
 
@@ -283,6 +316,7 @@ class ModelScenario:
         self,
         site: Optional[str] = None,
         inlet: Optional[str] = None,
+        height: Optional[str] = None,
         domain: Optional[str] = None,
         model: Optional[str] = None,
         metmodel: Optional[str] = None,
@@ -294,7 +328,7 @@ class ModelScenario:
         """
         Add footprint data based on keywords or direct FootprintData object.
         """
-        from openghg.util import clean_string, species_lifetime
+        from openghg.util import clean_string, format_inlet, species_lifetime
 
         # Search for footprint data based on keywords
         # - site, domain, inlet (can extract from obs), model, metmodel
@@ -302,6 +336,13 @@ class ModelScenario:
             site = clean_string(site)
             if inlet is None and self.obs is not None:
                 inlet = self.obs.metadata["inlet"]
+            elif inlet is None and height is not None:
+                inlet = height                        
+                inlet = clean_string(inlet)
+                inlet = format_inlet(inlet)
+            else:
+                inlet = clean_string(inlet)
+                inlet = format_inlet(inlet)
 
             # TODO: Add case to deal with "multiple" inlets
             if inlet == "multiple":
@@ -312,6 +353,7 @@ class ModelScenario:
             footprint_keywords = {
                 "site": site,
                 "height": inlet,
+                "inlet": inlet,
                 "domain": domain,
                 "model": model,  # Not currently used in get_footprint - should be added
                 # "metmodel": metmodel,  # Should be added to inputs for get_footprint()
@@ -327,7 +369,7 @@ class ModelScenario:
             if species_lifetime_value is not None or species == "co2":
                 footprint_keywords["species"] = species
 
-            footprint = self._get_data(footprint_keywords, input_type="footprint")
+            footprint = self._get_data(footprint_keywords, data_type="footprint")
 
         self.footprint = footprint
 
@@ -384,7 +426,7 @@ class ModelScenario:
 
                 # TODO: Add something to allow for e.g. global domain or no domain
 
-                flux_source = self._get_data(flux_keywords, input_type="flux")
+                flux_source = self._get_data(flux_keywords, data_type="flux")
                 # TODO: May need to update this check if flux_source is empty FluxData() object
                 if flux_source is not None:
                     flux[name] = flux_source
@@ -435,7 +477,7 @@ class ModelScenario:
                 "species": species,
             }
 
-            bc = self._get_data(bc_keywords, input_type="boundary_conditions")
+            bc = self._get_data(bc_keywords, data_type="boundary_conditions")
 
         self.bc = bc
 
@@ -987,6 +1029,8 @@ class ModelScenario:
         flux_modelled: DataArray = scenario["fp"] * flux["flux"]
         timeseries: DataArray = flux_modelled.sum(["lat", "lon"])
 
+        # TODO: Add details about units to output
+
         if output_TS and output_fpXflux:
             return timeseries, flux_modelled
         elif output_TS:
@@ -1246,6 +1290,8 @@ class ModelScenario:
                 # work out timeseries by summing over lat, lon (24 hrs)
                 timeseries[tt] = fpXflux_time.sum()
 
+        # TODO: Add details about units to output
+
         if output_fpXflux:
             fpXflux = DataArray(
                 fpXflux,
@@ -1273,6 +1319,7 @@ class ModelScenario:
         self,
         resample_to: str = "coarsest",
         platform: Optional[str] = None,
+        output_units: float = 1e-9,
         cache: bool = True,
         recalculate: bool = False,
     ) -> DataArray:
@@ -1374,14 +1421,22 @@ class ModelScenario:
             loss_s = 1.0
             loss_w = 1.0
 
+        # Check and extract units as float, if present.
+        units_default = 1.0
+        units_n = check_units(bc_data["vmr_n"], default=units_default)
+        units_e = check_units(bc_data["vmr_e"], default=units_default)
+        units_s = check_units(bc_data["vmr_s"], default=units_default)
+        units_w = check_units(bc_data["vmr_w"], default=units_default)
+
         modelled_baseline = (
-            (scenario["particle_locations_n"] * bc_data["vmr_n"] * loss_n).sum(["height", "lon"])
-            + (scenario["particle_locations_e"] * bc_data["vmr_e"] * loss_e).sum(["height", "lat"])
-            + (scenario["particle_locations_s"] * bc_data["vmr_s"] * loss_s).sum(["height", "lon"])
-            + (scenario["particle_locations_w"] * bc_data["vmr_w"] * loss_w).sum(["height", "lat"])
+            (scenario["particle_locations_n"] * bc_data["vmr_n"] * loss_n * units_n / output_units).sum(["height", "lon"])
+            + (scenario["particle_locations_e"] * bc_data["vmr_e"] * loss_e * units_e / output_units).sum(["height", "lat"])
+            + (scenario["particle_locations_s"] * bc_data["vmr_s"] * loss_s * units_s / output_units).sum(["height", "lon"])
+            + (scenario["particle_locations_w"] * bc_data["vmr_w"] * loss_w * units_w / output_units).sum(["height", "lat"])
         )
 
         modelled_baseline.attrs["resample_to"] = resample_to
+        modelled_baseline.attrs["units"] = output_units
         modelled_baseline = modelled_baseline.rename("bc_mod")
 
         # Cache output from calculations
@@ -1540,6 +1595,9 @@ class ModelScenario:
         else:
             label = f"Modelled {species.upper()}"
 
+        # TODO: Check modelled_obs units and ensure these match to modelled_baseline
+        # - currently modelled_baseline outputs in 1e-9 (ppb) by default.
+
         if baseline == "boundary_conditions":
             if self.bc is not None:
                 modelled_baseline = self.calc_modelled_baseline(
@@ -1763,6 +1821,27 @@ def stack_datasets(datasets: Sequence[Dataset], dim: str = "time", method: metho
     return data_stacked
 
 
+def check_units(data_var: DataArray, default: float) -> float:
+    """
+    Check "units" attribute within a DataArray. Expect this to be a float
+    or possible to convert to a float.
+    If not present, use default value.
+    """
+
+    attrs = data_var.attrs
+    if "units" in attrs:
+        units_from_attrs = attrs["units"]
+        if not isinstance(units_from_attrs, float):
+            try:
+                units = float(units_from_attrs)
+            except ValueError:
+                raise ValueError(f"Cannot extract {units_from_attrs} value as float")
+    else:
+        units = default
+
+    return units
+
+
 # def footprints_data_merge(data: Union[dict, ObsData],
 #                           domain: str,
 #                           met_model: Optional[str] = None,
