@@ -4,5 +4,7 @@ from ._flux_data import FluxData
 from ._footprint_data import FootprintData
 from ._metdata import METData
 from ._obsdata import ObsData
+from ._obscolumn_data import ObsColumnData
 from ._ranksources import RankSources
 from ._searchresults import SearchResults
+from ._datahandler import DataHandler
