@@ -1,5 +1,5 @@
 from pathlib import Path
-from typing import Dict, Optional, Union
+from typing import Dict, Literal, Optional, Union
 
 
 def parse_openghg(
@@ -7,9 +7,10 @@ def parse_openghg(
     species: str,
     source: str,
     domain: str,
-    date: Optional[str] = None,
+    data_type: str,
     high_time_resolution: Optional[bool] = False,
     period: Optional[Union[str, tuple]] = None,
+    chunks: Union[int, Dict, Literal["auto"], None] = None,
     continuous: bool = True,
 ) -> Dict:
     """
@@ -17,6 +18,8 @@ def parse_openghg(
 
     Args:
         filepath: Path to data file
+        chunks: Chunk size to use when parsing NetCDF, useful for large datasets.
+        Passing "auto" will ask xarray to calculate a chunk size.
     Returns:
         dict: Dictionary of data
     """
@@ -25,7 +28,7 @@ def parse_openghg(
     from openghg.util import timestamp_now
     from xarray import open_dataset
 
-    em_data = open_dataset(filepath)
+    em_data = open_dataset(filepath, chunks=chunks)
 
     # Some attributes are numpy types we can't serialise to JSON so convert them
     # to their native types here
@@ -45,9 +48,11 @@ def parse_openghg(
     metadata["species"] = species
     metadata["domain"] = domain
     metadata["source"] = source
-    metadata["date"] = date
     metadata["author"] = author_name
+    metadata["data_type"] = data_type
     metadata["processed"] = str(timestamp_now())
+    metadata["data_type"] = "emissions"
+    metadata["source_format"] = "openghg"
 
     # As emissions files handle things slightly differently we need to check the time values
     # more carefully.
@@ -60,15 +65,6 @@ def parse_openghg(
         em_time, filepath=filepath, period=period, continuous=continuous
     )
 
-    if date is None:
-        # Check for how granular we should make the date label
-        if "year" in period_str:
-            date = f"{start_date.year}"
-        elif "month" in period_str:
-            date = f"{start_date.year}{start_date.month:02}"
-        else:
-            date = start_date.astype("datetime64[s]").astype(str)
-
     metadata["start_date"] = str(start_date)
     metadata["end_date"] = str(end_date)
 
@@ -80,7 +76,7 @@ def parse_openghg(
     metadata["time_resolution"] = "high" if high_time_resolution else "standard"
     metadata["time_period"] = period_str
 
-    key = "_".join((species, source, domain, date))
+    key = "_".join((species, source, domain))
 
     emissions_data: Dict[str, dict] = {}
     emissions_data[key] = {}
