@@ -13,6 +13,7 @@ def parse_noaa(
     network: str = "NOAA",
     instrument: Optional[str] = None,
     sampling_period: Optional[str] = None,
+    **kwarg: Dict,
 ) -> Dict:
     """Read NOAA data from raw text file or ObsPack NetCDF
 
@@ -614,6 +615,8 @@ def _read_raw_data(
     metadata["inlet"] = inlet
     metadata["sampling_period"] = sampling_period
     metadata["instrument"] = noaa_params["instrument"][species.upper()]
+    metadata["data_type"] = "surface"
+    metadata["source_format"] = "noaa"
 
     combined_data[species.lower()] = {
         "metadata": metadata,
