@@ -1,16 +1,18 @@
+import logging
 from collections import defaultdict
 from pathlib import Path
-from tempfile import TemporaryDirectory
-from typing import DefaultDict, Dict, List, NoReturn, Optional, Tuple, Union
+from typing import DefaultDict, Dict, Literal, List, Optional, Tuple, Union, cast
 
 import numpy as np
 from openghg.store import DataSchema
 from openghg.store.base import BaseStore
-from pandas import Timestamp
 from xarray import Dataset
 
 __all__ = ["Footprints"]
 
+logger = logging.getLogger("openghg.store")
+logger.setLevel(logging.DEBUG)  # Have to set level for logger as well as handler
+
 
 class Footprints(BaseStore):
     """This class is used to process footprints model output"""
@@ -20,7 +22,7 @@ class Footprints(BaseStore):
     _metakey = f"{_root}/uuid/{_uuid}/metastore"
 
     @staticmethod
-    def read_data(binary_data: bytes, metadata: Dict, file_metadata: Dict) -> Dict:
+    def read_data(binary_data: bytes, metadata: Dict, file_metadata: Dict) -> Optional[Dict]:
         """Ready a footprint from binary data
 
         Args:
@@ -30,18 +32,19 @@ class Footprints(BaseStore):
         Returns:
             dict: UUIDs of Datasources data has been assigned to
         """
-        with TemporaryDirectory() as tmpdir:
-            tmpdir_path = Path(tmpdir)
+        raise NotImplementedError("This branch doesn't currently support cloud.")
+        # with TemporaryDirectory() as tmpdir:
+        #     tmpdir_path = Path(tmpdir)
 
-            try:
-                filename = file_metadata["filename"]
-            except KeyError:
-                raise KeyError("We require a filename key for metadata read.")
+        #     try:
+        #         filename = file_metadata["filename"]
+        #     except KeyError:
+        #         raise KeyError("We require a filename key for metadata read.")
 
-            filepath = tmpdir_path.joinpath(filename)
-            filepath.write_bytes(binary_data)
+        #     filepath = tmpdir_path.joinpath(filename)
+        #     filepath.write_bytes(binary_data)
 
-            return Footprints.read_file(filepath=filepath, **metadata)
+        #     return Footprints.read_file(filepath=filepath, **metadata)
 
     # @staticmethod
     # def read_data(binary_data: bytes, metadata: Dict, file_metadata: Dict) -> Dict:
@@ -183,13 +186,15 @@ class Footprints(BaseStore):
     def read_file(
         filepath: Union[str, Path],
         site: str,
-        height: str,
         domain: str,
         model: str,
+        inlet: Optional[str] = None,
+        height: Optional[str] = None,
         metmodel: Optional[str] = None,
         species: Optional[str] = None,
         network: Optional[str] = None,
         period: Optional[Union[str, tuple]] = None,
+        chunks: Union[int, Dict, Literal["auto"], None] = None,
         continuous: bool = True,
         retrieve_met: bool = False,
         high_spatial_res: bool = False,
@@ -197,16 +202,17 @@ class Footprints(BaseStore):
         short_lifetime: bool = False,
         overwrite: bool = False,
         # model_params: Optional[Dict] = None,
-    ) -> Dict[str, Dict]:
+    ) -> Optional[Dict]:
         """Reads footprints data files and returns the UUIDS of the Datasources
         the processed data has been assigned to
 
         Args:
             filepath: Path of file to load
             site: Site name
-            height: Height above ground level in metres
             domain: Domain of footprints
             model: Model used to create footprint (e.g. NAME or FLEXPART)
+            inlet: Height above ground level in metres. Format 'NUMUNIT' e.g. "10m"
+            height: Alias for inlet. One of height or inlet must be included.
             metmodel: Underlying meteorlogical model used (e.g. UKV)
             species: Species name. Only needed if footprint is for a specific species e.g. co2 (and not inert)
             network: Network name
@@ -219,21 +225,32 @@ class Footprints(BaseStore):
             short_lifetime: Indicate footprint is for a short-lived species. Needs species input.
                             Note this will be set to True if species has an associated lifetime.
             overwrite: Overwrite any currently stored data
-
         Returns:
             dict: UUIDs of Datasources data has been assigned to
         """
+        # from xarray import load_dataset
+        import xarray as xr
         from openghg.store import assign_data, datasource_lookup, infer_date_range, load_metastore
-        from openghg.util import clean_string, hash_file, species_lifetime, timestamp_now
-        from xarray import open_dataset
+        from openghg.util import clean_string, format_inlet, hash_file, species_lifetime, timestamp_now
 
         filepath = Path(filepath)
 
         site = clean_string(site)
         network = clean_string(network)
-        height = clean_string(height)
         domain = clean_string(domain)
 
+        # Make sure `inlet` OR the alias `height` is included
+        # Note: from this point only `inlet` variable should be used.
+        if inlet is None and height is None:
+            raise ValueError("One of inlet (or height) must be specified as an input")
+        elif inlet is None:
+            inlet = height
+
+        # Try to ensure inlet is 'NUM''UNIT' e.g. "10m"
+        inlet = clean_string(inlet)
+        inlet = format_inlet(inlet)
+        inlet = cast(str, inlet)
+
         fp = Footprints.load()
 
         # Load in the metadata store
@@ -241,11 +258,13 @@ class Footprints(BaseStore):
 
         file_hash = hash_file(filepath=filepath)
         if file_hash in fp._file_hashes and not overwrite:
-            print(
+            logger.warning(
                 f"This file has been uploaded previously with the filename : {fp._file_hashes[file_hash]} - skipping."
             )
+            return None
 
-        fp_data = open_dataset(filepath)
+        # Load this into memory
+        fp_data = xr.open_dataset(filepath, chunks=chunks)
 
         if species == "co2":
             # Expect co2 data to have high time resolution
@@ -279,10 +298,13 @@ class Footprints(BaseStore):
 
         metadata["data_type"] = "footprints"
         metadata["site"] = site
-        metadata["height"] = height
         metadata["domain"] = domain
         metadata["model"] = model
 
+        # Include both inlet and height keywords for backwards compatability
+        metadata["inlet"] = inlet
+        metadata["height"] = inlet
+
         if species is not None:
             metadata["species"] = clean_string(species)
 
@@ -337,7 +359,7 @@ class Footprints(BaseStore):
 
         # This might seem longwinded now but will help when we want to read
         # more than one footprints at a time
-        key = "_".join((site, domain, model, height))
+        key = "_".join((site, domain, model, inlet))
 
         footprint_data: DefaultDict[str, Dict[str, Union[Dict, Dataset]]] = defaultdict(dict)
         footprint_data[key]["data"] = fp_data
@@ -346,7 +368,7 @@ class Footprints(BaseStore):
         # These are the keys we will take from the metadata to search the
         # metadata store for a Datasource, they should provide as much detail as possible
         # to uniquely identify a Datasource
-        required = ("site", "model", "height", "domain")
+        required = ("site", "model", "inlet", "domain")
         lookup_results = datasource_lookup(metastore=metastore, data=footprint_data, required_keys=required)
 
         data_type = "footprints"
@@ -364,6 +386,7 @@ class Footprints(BaseStore):
 
         fp.save()
 
+        fp_data.close()
         metastore.close()
 
         return datasource_uuids
@@ -493,23 +516,3 @@ class Footprints(BaseStore):
             short_lifetime=short_lifetime,
         )
         data_schema.validate_data(data)
-
-    def search(
-        self,
-        site: str,
-        network: str,
-        start_date: Optional[Union[str, Timestamp]],
-        end_date: Optional[Union[str, Timestamp]],
-    ) -> NoReturn:
-        """Search for a footprints from a specific site and network, return a dictionary of data
-        so the user can choose
-        """
-        raise NotImplementedError()
-
-    def retrieve(self, uuid: str, dates: str) -> NoReturn:
-        """"""
-        raise NotImplementedError()
-
-    def _get_metdata(self) -> NoReturn:
-        """This retrieves the metadata for this footprints"""
-        raise NotImplementedError()
