@@ -21,6 +21,14 @@ class ObsSurface(BaseStore):
     _uuid = "da0b8b44-6f85-4d3c-b6a3-3dde34f6dea1"
     _metakey = f"{_root}/uuid/{_uuid}/metastore"
 
+    # @staticmethod
+    # def load_metastore() -> TinyDB:
+    #     """ Load the ObsSurface metadata store
+
+    #     Returns:
+    #         TinyDB: TinyDB object
+    #     """
+
     @staticmethod
     def read_data(
         binary_data: bytes, metadata: Dict, file_metadata: Dict, precision_data: Optional[bytes] = None
@@ -43,7 +51,7 @@ class ObsSurface(BaseStore):
         from tempfile import TemporaryDirectory
 
         possible_kwargs = {
-            "data_type",
+            "source_format",
             "network",
             "site",
             "inlet",
@@ -51,6 +59,8 @@ class ObsSurface(BaseStore):
             "sampling_period",
             "measurement_type",
             "overwrite",
+            "source_format",
+            "data_type",
         }
 
         # We've got a lot of functions that expect a file and read
@@ -88,12 +98,14 @@ class ObsSurface(BaseStore):
     @staticmethod
     def read_file(
         filepath: multiPathType,
-        data_type: str,
+        source_format: str,
         network: str,
         site: str,
         inlet: Optional[str] = None,
+        height: Optional[str] = None,
         instrument: Optional[str] = None,
         sampling_period: Optional[str] = None,
+        calibration_scale: Optional[str] = None,
         measurement_type: str = "insitu",
         overwrite: bool = False,
         verify_site_code: bool = True,
@@ -104,10 +116,13 @@ class ObsSurface(BaseStore):
 
         Args:
             filepath: Filepath(s)
-            data_type: Data type, for example CRDS, GCWERKS
+            source_format: Data format, for example CRDS, GCWERKS
             site: Site code/name
             network: Network name
-            inlet: Inlet height. If retrieve multiple files pass None, OpenGHG will attempt to
+            inlet: Inlet height. Format 'NUMUNIT' e.g. "10m".
+                If retrieve multiple files pass None, OpenGHG will attempt to
+                extract this from the file.
+            height: Alias for inlet.
             read inlets from data.
             instrument: Instrument name
             sampling_period: Sampling period in pandas style (e.g. 2H for 2 hour period, 2m for 2 minute period).
@@ -116,13 +131,16 @@ class ObsSurface(BaseStore):
             verify_site_code: Verify the site code
         Returns:
             dict: Dictionary of Datasource UUIDs
+
+        TODO: Should "measurement_type" be changed to "platform" to align
+        with ModelScenario and ObsColumn?
         """
         import sys
         from collections import defaultdict
 
         from openghg.store import assign_data, datasource_lookup, load_metastore
         from openghg.types import SurfaceTypes
-        from openghg.util import clean_string, hash_file, load_surface_parser, verify_site
+        from openghg.util import clean_string, format_inlet, hash_file, load_surface_parser, verify_site
         from pandas import Timedelta
         from tqdm import tqdm
 
@@ -130,19 +148,26 @@ class ObsSurface(BaseStore):
             filepath = [filepath]
 
         try:
-            data_type = SurfaceTypes[data_type.upper()].value
+            source_format = SurfaceTypes[source_format.upper()].value
         except KeyError:
-            raise ValueError(f"Unknown data type {data_type} selected.")
+            raise ValueError(f"Unknown data type {source_format} selected.")
 
         # Test that the passed values are valid
         # Check validity of site, instrument, inlet etc in acrg_site_info.json
         # Clean the strings
         site = verify_site(site=site) if verify_site_code else clean_string(site)
         network = clean_string(network)
-        inlet = clean_string(inlet)
         instrument = clean_string(instrument)
         # sampling_period = clean_string(sampling_period)
 
+        # Check if alias `height` is included instead of `inlet`
+        if inlet is None and height is not None:
+            inlet = height        
+
+        # Try to ensure inlet is 'NUM''UNIT' e.g. "10m"
+        inlet = clean_string(inlet)
+        inlet = format_inlet(inlet)
+
         sampling_period_seconds: Union[str, None] = None
         # If we have a sampling period passed we want the number of seconds
         if sampling_period is not None:
@@ -154,7 +179,7 @@ class ObsSurface(BaseStore):
                 )
 
         # Load the data retrieve object
-        parser_fn = load_surface_parser(data_type=data_type)
+        parser_fn = load_surface_parser(source_format=source_format)
 
         obs = ObsSurface.load()
 
@@ -166,7 +191,10 @@ class ObsSurface(BaseStore):
         # Create a progress bar object using the filepaths, iterate over this below
         with tqdm(total=len(filepath), file=sys.stdout) as progress_bar:
             for fp in filepath:
-                if data_type == "GCWERKS":
+                if source_format == "GCWERKS":
+                    if not isinstance(fp, tuple):
+                        raise TypeError("For GCWERKS data we expect a tuple of (data file, precision file).")
+
                     try:
                         data_filepath = Path(fp[0])
                         precision_filepath = Path(fp[1])
@@ -183,10 +211,11 @@ class ObsSurface(BaseStore):
                         "This file has been uploaded previously with the filename : "
                         f"{obs._file_hashes[file_hash]} - skipping."
                     )
+                    break
 
                 progress_bar.set_description(f"Processing: {data_filepath.name}")
 
-                if data_type == "GCWERKS":
+                if source_format == "GCWERKS":
                     data = parser_fn(
                         data_filepath=data_filepath,
                         precision_filepath=precision_filepath,
@@ -206,6 +235,7 @@ class ObsSurface(BaseStore):
                         instrument=instrument,
                         sampling_period=sampling_period_seconds,
                         measurement_type=measurement_type,
+                        calibration_scale=calibration_scale,
                     )
 
                 # Current workflow: if any species fails, whole filepath fails
@@ -234,7 +264,7 @@ class ObsSurface(BaseStore):
                 #     try:
                 #         ObsSurface.validate_data(value["data"], species=species)
                 #     except ValueError:
-                #         print(f"WARNING: standardised data for '{data_type}' is not in expected OpenGHG format.")
+                #         print(f"WARNING: standardised data for '{source_format}' is not in expected OpenGHG format.")
                 #         print(f"Check data for {species}")
                 #         print(value["data"])
                 #         print("Not writing to object store.")
@@ -251,9 +281,10 @@ class ObsSurface(BaseStore):
                     "inlet",
                     "instrument",
                     "network",
-                    "data_type",
+                    "source_format",
                     "data_source",
                     "icos_data_level",
+                    "data_type",
                 )
 
                 lookup_results = datasource_lookup(
@@ -261,8 +292,12 @@ class ObsSurface(BaseStore):
                 )
 
                 # Create Datasources, save them to the object store and get their UUIDs
+                data_type = "surface"
                 datasource_uuids = assign_data(
-                    data_dict=data, lookup_results=lookup_results, overwrite=overwrite
+                    data_dict=data,
+                    lookup_results=lookup_results,
+                    overwrite=overwrite,
+                    data_type=data_type,
                 )
 
                 results["processed"][data_filepath.name] = datasource_uuids
@@ -278,8 +313,8 @@ class ObsSurface(BaseStore):
 
                 progress_bar.update(1)
 
-            logger.info(f"Completed processing: {data_filepath.name}.")
-            logger.info(f"\tUUIDs: {datasource_uuids}")
+                logger.info(f"Completed processing: {data_filepath.name}.")
+                logger.info(f"\tUUIDs: {datasource_uuids}")
 
         # Ensure we explicitly close the metadata store
         # as we're using the cached storage method
@@ -334,6 +369,7 @@ class ObsSurface(BaseStore):
                 raise ValueError(
                     f"This file has been uploaded previously with the filename : {obs._file_hashes[file_hash]}."
                 )
+                break
 
             combined = {site: {"data": measurement_data, "metadata": metadata}}
 
@@ -359,8 +395,12 @@ class ObsSurface(BaseStore):
             lookup_result = {site: uuid}
 
             # Create Datasources, save them to the object store and get their UUIDs
+            data_type = "surface"
             datasource_uuids = assign_data(
-                data_dict=combined, lookup_results=lookup_result, overwrite=overwrite
+                data_dict=combined,
+                lookup_results=lookup_result,
+                overwrite=overwrite,
+                data_type=data_type,
             )
 
             results[site] = datasource_uuids
@@ -402,9 +442,9 @@ class ObsSurface(BaseStore):
         data_vars: Dict[str, Tuple[str, ...]] = {name: ("time",)}
         dtypes = {name: np.floating, "time": np.datetime64}
 
-        data_format = DataSchema(data_vars=data_vars, dtypes=dtypes)
+        source_format = DataSchema(data_vars=data_vars, dtypes=dtypes)
 
-        return data_format
+        return source_format
 
     @staticmethod
     def validate_data(data: Dataset, species: str) -> None:
@@ -438,7 +478,7 @@ class ObsSurface(BaseStore):
             required_metakeys: Keys in the metadata we should use to store this metadata in the object store
             if None it defaults to:
             {"species", "site", "station_long_name", "inlet", "instrument",
-            "network", "data_type", "data_source", "icos_data_level"}
+            "network", "source_format", "data_source", "icos_data_level"}
         Returns:
             Dict or None:
         """
@@ -473,7 +513,7 @@ class ObsSurface(BaseStore):
                 "inlet",
                 "instrument",
                 "network",
-                "data_type",
+                "source_format",
                 "data_source",
                 "icos_data_level",
             )
@@ -486,8 +526,12 @@ class ObsSurface(BaseStore):
         )
 
         # Create Datasources, save them to the object store and get their UUIDs
+        data_type = "surface"
         datasource_uuids = assign_data(
-            data_dict=to_process, lookup_results=lookup_results, overwrite=overwrite
+            data_dict=to_process,
+            lookup_results=lookup_results,
+            overwrite=overwrite,
+            data_type=data_type,
         )
 
         # Record the Datasources we've created / appended to
@@ -523,7 +567,9 @@ class ObsSurface(BaseStore):
             None
         """
         from openghg.objectstore import delete_object, get_bucket
+        from openghg.store import load_metastore
         from openghg.store.base import Datasource
+        from tinydb import where
 
         bucket = get_bucket()
         # Load the Datasource and get all its keys
@@ -543,6 +589,11 @@ class ObsSurface(BaseStore):
         key = f"{Datasource._datasource_root}/uuid/{uuid}"
         delete_object(bucket=bucket, key=key)
 
+        # Delete the UUID from the metastore
+        metastore = load_metastore(key=self._metakey)
+        metastore.remove(where("uuid") == uuid)
+        metastore.close
+
         del self._datasource_uuids[uuid]
 
     def seen_hash(self, file_hash: str) -> bool:
