@@ -2,7 +2,7 @@ from __future__ import annotations
 
 from typing import TYPE_CHECKING
 
-from openghg.util import running_locally
+# from openghg.util import running_locally
 
 if TYPE_CHECKING:
     from openghg.dataobjects import RankSources
@@ -18,10 +18,11 @@ def rank_sources(site: str, species: str, service_url: str = None) -> RankSource
     Returns:
         RankSources: A RankSources object
     """
-    from openghg.dataobjects import RankSources
+    raise NotImplementedError
+    # from openghg.dataobjects import RankSources
 
-    hub_or_cloud = not running_locally()
-    ranker = RankSources(cloud=hub_or_cloud, service_url=service_url)
-    ranker.get_sources(site=site, species=species)
+    # hub_or_cloud = not running_locally()
+    # ranker = RankSources(cloud=hub_or_cloud, service_url=service_url)
+    # ranker.get_sources(site=site, species=species)
 
-    return ranker
+    # return ranker
