@@ -1,6 +1,7 @@
 from typing import DefaultDict, Dict, List, Optional, Tuple, Type, TypeVar, Union
 
 import numpy as np
+from openghg.store.spec import define_data_types
 from pandas import DataFrame, Timestamp
 from xarray import Dataset
 
@@ -17,7 +18,6 @@ class Datasource:
     """
 
     _datasource_root = "datasource"
-    _datavalues_root = "values"
     _data_root = "data"
 
     def __init__(self) -> None:
@@ -39,7 +39,7 @@ class Datasource:
         # This dictionary stored the keys for each version of data uploaded
         # data_key = d._data_keys["latest"]["keys"][date_key]
         self._data_keys: dataKeyType = defaultdict(dict)
-        self._data_type: str = "timeseries"
+        self._data_type: str = ""
         # Hold information regarding the versions of the data
         # Currently unused
         self._latest_version: str = "latest"
@@ -87,19 +87,12 @@ class Datasource:
         Args:
             metadata: Metadata on the data for this Datasource
             data: xarray.Dataset
-            data_type: Type of data, one of ["timeseries", "emissions", "met", "footprints", "eulerian_model"].
+            data_type: Type of data, one of ["surface", "emissions", "met", "footprints", "eulerian_model"].
             overwrite: Overwrite existing data
         Returns:
             None
         """
-        expected_data_types = (
-            "timeseries",
-            "emissions",
-            "met",
-            "footprints",
-            "boundary_conditions",
-            "eulerian_model",
-        )
+        expected_data_types = define_data_types()
 
         data_type = data_type.lower()
         if data_type not in expected_data_types:
@@ -124,19 +117,26 @@ class Datasource:
         from openghg.util import daterange_overlap
         from xarray import concat as xr_concat
 
+        # For now we'll only group timeseries data.
+        # This is to a
+        # if data_type != "timeseries"
         # Group by year
-        year_group = data.groupby("time.year")
-
-        # Use a dictionary keyed with the daterange covered by each segment of data
-        new_data = {}
-
+        # year_group = data.groupby("time.year")
         # Extract period associated with data from metadata
         # TODO: May want to add period as a potential data variable so would need to extract from there if needed
         period = self.get_period()
 
-        for _, data in year_group:
-            daterange_str = self.get_representative_daterange_str(data, period=period)
-            new_data[daterange_str] = data
+        new_data = {
+            self.get_representative_daterange_str(year_data, period=period): year_data
+            for _, year_data in data.groupby("time.year")
+        }
+
+        # Use a dictionary keyed with the daterange covered by each segment of data
+        # new_data = {}
+
+        # for _, data in year_group:
+        #     daterange_str = self.get_representative_daterange_str(data, period=period)
+        #     new_data[daterange_str] = data
 
         if self._data:
             # We need to remove them from the curre
@@ -207,6 +207,54 @@ class Datasource:
         self._data_type = data_type
         self.add_metadata_key(key="data_type", value=data_type)
         self.update_daterange()
+        # Store the start and end date of the most recent data
+        start, end = self.daterange()
+        self.add_metadata_key(key="start_date", value=str(start))
+        self.add_metadata_key(key="end_date", value=str(end))
+
+    def delete_all_data(self) -> None:
+        """Delete the data associated with this Datasource
+
+        Returns:
+            None
+        """
+        from openghg.objectstore import delete_object, get_bucket
+
+        bucket = get_bucket()
+
+        to_delete = []
+        for key_data in self._data_keys.values():
+            keys = list(key_data["keys"].values())
+            to_delete.extend(keys)
+
+        for key in set(to_delete):
+            delete_object(bucket=bucket, key=key)
+
+    def delete_data(self, keys: List) -> None:
+        """Delete specific keys
+
+        Args:
+            keys: List of keys to delete
+        """
+        from openghg.objectstore import delete_object, get_bucket
+
+        bucket = get_bucket()
+
+        for key in set(keys):
+            delete_object(bucket=bucket, key=key)
+
+    # def delete_version(self, version: str) -> None:
+    #     """Delete a specific version of data.
+
+    #     Args:
+    #         version: Version string
+    #     Returns:
+    #         None
+    #     """
+    #     if version not in self._data_keys:
+    #         raise KeyError("Invalid version.")
+
+    #     # keys =
 
     def add_metadata(self, metadata: Dict) -> None:
         """Add all metadata in the dictionary to this Datasource
@@ -409,24 +457,22 @@ class Datasource:
         Returns:
             xarray.Dataset: Dataset from NetCDF file
         """
-        import tempfile
-        from pathlib import Path
-
+        import io
         from openghg.objectstore import get_object
         from xarray import load_dataset
 
-        data = get_object(bucket, key)
+        return load_dataset(io.BytesIO(get_object(bucket=bucket, key=key)))
 
-        # TODO - is there a cleaner way of doing this?
-        with tempfile.TemporaryDirectory() as tmpdir:
-            tmp_path = Path(tmpdir).joinpath("tmp.nc")
+        # # TODO - is there a cleaner way of doing this?
+        # with tempfile.TemporaryDirectory() as tmpdir:
+        #     tmp_path = Path(tmpdir).joinpath("tmp.nc")
 
-            with open(tmp_path, "wb") as f:
-                f.write(data)
+        #     with open(tmp_path, "wb") as f:
+        #         f.write(data)
 
-            ds: Dataset = load_dataset(tmp_path)
+        #     ds: Dataset = xr_load_dataset(tmp_path)
 
-            return ds
+        #     return ds
 
     @classmethod
     def from_data(cls: Type[T], bucket: str, data: Dict, shallow: bool) -> T:
@@ -470,10 +516,10 @@ class Datasource:
         Returns:
             None
         """
-        import tempfile
         from copy import deepcopy
+        from pathlib import Path
 
-        from openghg.objectstore import get_bucket, set_object_from_file, set_object_from_json
+        from openghg.objectstore import get_bucket, set_object_from_json
         from openghg.util import timestamp_now
 
         if bucket is None:
@@ -496,12 +542,21 @@ class Datasource:
                 new_keys[daterange] = data_key
                 data = self._data[daterange]
 
+                filepath = Path(f"{bucket}/{data_key}._data")
+                parent_folder = filepath.parent
+                if not parent_folder.exists():
+                    parent_folder.mkdir(parents=True, exist_ok=True)
+
+                data.to_netcdf(filepath)
+
+                # Can we just take the bytes from the data here and then write then straight?
                 # TODO - for now just create a temporary directory - will have to update Acquire
                 # or work on a PR for xarray to allow returning a NetCDF as bytes
-                with tempfile.TemporaryDirectory() as tmpdir:
-                    filepath = f"{tmpdir}/temp.nc"
-                    data.to_netcdf(filepath)
-                    set_object_from_file(bucket=bucket, key=data_key, filename=filepath)
+                # with tempfile.TemporaryDirectory() as tmpdir:
+                #     filepath = f"{tmpdir}/temp.nc"
+                #     data.to_netcdf(filepath)
+                #     set_object_from_file(bucket=bucket, key=data_key, filename=filepath)
+                # path = f"{bucket_path}/data"
 
             # Copy the last version
             if "latest" in self._data_keys:
@@ -520,6 +575,14 @@ class Datasource:
 
         set_object_from_json(bucket=bucket, key=datasource_key, data=self.to_data())
 
+    def key(self) -> str:
+        """Returns the Datasource's key
+
+        Returns:
+            str: Key for Datasource in object store
+        """
+        return f"{Datasource._datasource_root}/uuid/{self._uuid}"
+
     @classmethod
     def load(
         cls: Type[T],
@@ -726,15 +789,15 @@ class Datasource:
         Returns:
             bool: True if overlap
         """
+        from openghg.util import in_daterange as _in_daterange
         from openghg.util import timestamp_tzaware
 
-        # if self._start_date is None or self._end_date is None:
-        #     self.update_daterange()
-
         start_date = timestamp_tzaware(start_date)
         end_date = timestamp_tzaware(end_date)
 
-        return bool((start_date <= self._end_date) and (end_date >= self._start_date))
+        return _in_daterange(
+            start_a=start_date, end_a=end_date, start_b=self._start_date, end_b=self._end_date
+        )
 
     def keys_in_daterange(
         self, start_date: Union[str, Timestamp], end_date: Union[str, Timestamp]
