@@ -57,6 +57,7 @@ def parse_edgar(
     Returns:
         dict: Dictionary of data
 
+    TODO: Allow date range to be extracted rather than year?
     TODO: Add monthly parsing and sector stacking options
     """
     import tempfile
@@ -323,6 +324,7 @@ def parse_edgar(
     metadata["database_version"] = database_version
     metadata["author"] = author_name
     metadata["processed"] = str(timestamp_now())
+    metadata["data_type"] = "emissions"
 
     attrs = {"author": metadata["author"], "processed": metadata["processed"]}
 
